@@ -212,12 +212,13 @@ graph
         fh.seek(0)
         pytest.raises(nx.NetworkXError, nx.read_gml, fh, label="label")
 
-    def test_tuplelabels(self):
+    @pytest.mark.parametrize("stringizer", (None, literal_stringizer))
+    def test_tuplelabels(self, stringizer):
         # https://github.com/networkx/networkx/pull/1048
         # Writing tuple labels to GML failed.
         G = nx.Graph()
         G.add_edge((0, 1), (1, 0))
-        data = "\n".join(nx.generate_gml(G, stringizer=literal_stringizer))
+        data = "\n".join(nx.generate_gml(G, stringizer=stringizer))
         answer = """graph [
   node [
     id 0
@@ -614,6 +615,28 @@ graph
             os.close(fd)
             os.unlink(fname)
 
+    def test_multiline(self):
+        # example from issue #6836
+        multiline_example = """
+graph
+[
+    node
+    [
+	    id 0
+	    label "multiline node"
+	    label2 "multiline1
+    multiline2
+    multiline3"
+	    alt_name "id 0"
+    ]
+]
+"""
+        G = nx.parse_gml(multiline_example)
+        assert G.nodes["multiline node"] == {
+            "label2": "multiline1 multiline2 multiline3",
+            "alt_name": "id 0",
+        }
+
 
 @contextmanager
 def byte_file():
